/*
 * GraphColorHelper.java
 * Created on 2011/10/13
 *
 * Copyright (C) 2011-2013 Nippon Telegraph and Telephone Corporation
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

package jp.co.ntt.oss.heapstats.gui.graph;

import java.awt.Paint;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import jp.co.ntt.oss.heapstats.container.MapKey;

import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.plot.DefaultDrawingSupplier;
import org.jfree.chart.plot.DrawingSupplier;
import org.jfree.chart.plot.PiePlot;
import org.jfree.chart.plot.Plot;
import org.jfree.data.category.DefaultCategoryDataset;
import org.jfree.data.general.Dataset;
import org.jfree.data.general.DefaultPieDataset;

/**
 * This class creates a color corresponding to the class path.
 */
public final class GraphColorHelper {
    /** Map and color that corresponds to the class path. */
    private static Map<String, Paint> colorMap = new HashMap<String, Paint>();

    /** Managing drawing the next in the sequence. */
    private static DrawingSupplier colorSupply = new DefaultDrawingSupplier();

    /**
     * Don't let anyone instantiate this class.
     */
    private GraphColorHelper() {
    }

    /**
     * Automatically configure the color corresponding to each class.
     *
     * @param dataset the graphics Dataset.
     * @param plot the Graph plot.
     */
    public static void adjustColor(final Dataset dataset, final Plot plot) {
        List<MapKey> keys;
        Paint plotColor;
        boolean isPieChart;

        if (dataset instanceof DefaultPieDataset) {
            keys = ((DefaultPieDataset) dataset).getKeys();
            isPieChart = true;
        } else {
            keys = ((DefaultCategoryDataset) dataset).getRowKeys();
            isPieChart = false;
        }

        for (MapKey key : keys) {
            plotColor = colorMap.get(key.getName());

            if (plotColor == null) {
                plotColor = colorSupply.getNextPaint();
                colorMap.put(key.getName(), plotColor);
            }

            if (isPieChart) {
                ((PiePlot) plot).setSectionPaint(key, plotColor);
            } else {
                ((CategoryPlot) plot).getRenderer().setSeriesPaint(
                        ((DefaultCategoryDataset) dataset).getRowIndex(key),
                        plotColor);
            }
        }
    }

    /**
     * Paint for the classes to return the path.
     *
     * @param name the Class path
     * @return Return the Paint
     */
    public static Paint getColor(final String name) {
        Paint plotColor = null;
        plotColor = colorMap.get(name);

        return plotColor;
    }
}
